import numpy as np
from . import transform

class circle:
	"""This class defines an object of type circle. 
	Attributes: 
		center: (0,0) by default
		radius
		fill_type"""
	
	def __init__(self, radius, center=(0,0),pts=100):
		self.r = radius
		self.xc , self.yc = center
		
		self.perimeter = 2*np.pi*self.r
		self.area = np.pi*self.r**2
		self.theta = np.linspace(0,2*np.pi,pts)
		self.x = self.r*np.cos(self.theta) + self.xc
		self.y = self.r*np.sin(self.theta) + self.yc
		return
		
		

class ellipse:
	"""This class defines an object of type ellipse"""
	
	def __init__(self, maj_mi_tuple = (1,2), center=(0,0),pts=100):
		
		self.major_axis, self.minor_axis = maj_mi_tuple
		self.xc , self.yc = center
		self.perimeter = np.pi*(self.major_axis + self.minor_axis)
		
		#self.area = np.pi*self.major_axis*self.minor_axis
		self.theta = np.linspace(0,2*np.pi,pts)
		self.x = self.major_axis*np.cos(self.theta) + self.xc
		self.y = self.minor_axis*np.sin(self.theta) + self.yc
		
	def rotate(self,theta):
		#print('rotate by theta', theta)
		x_rot, y_rot = transform.rotate(self.x-self.xc,self.y-self.yc,theta)
		
		self.x = x_rot + self.xc
		self.y = y_rot + self.yc

		
		






import numpy as np

from . import transform

class rectangle:
	"""This class defines an object of type rectangle. 
	Attributes: 
		center: (0,0) by default
		radius
		fill_type"""
	
	def __init__(self, ab_tuple = (1,1), center=(0,0),pts=100):
		print(ab_tuple)
		self.xc, self.yc = center
		
		self.a, self.b = ab_tuple
		
		pts_by_2 = int(pts/2)
		
		pts_a = int(pts_by_2*self.a/(self.a+self.b))
		pts_b = pts_by_2 - pts_a
		print(pts_b)
		
		self.perimeter = 2*(self.a+self.b)
		self.area = self.a * self.b
		
		#self.x = np.linspace(-self.a/2,self.a/2,pts_a) 
		#self.y = -self.b/2*np.ones(pts_a) + self.yc
		
		
		'''Top arm'''
		x_t = np.linspace(-self.a/2,self.a/2,pts_a) 
		y_t = self.b/2*np.ones(pts_a)
		
		'''Right arm'''
		x_r = self.a/2*np.ones(pts_b)
		y_r = np.linspace(self.b/2,-self.b/2,pts_b) 
		
		
		'''Bottom arm'''
		x_b = np.linspace(self.a/2,-self.a/2,pts_a) 
		y_b = -self.b/2*np.ones(pts_a)
		
		
		'''Left arm'''
		x_l = -self.a/2*np.ones(pts_b)
		y_l = np.linspace(-self.b/2,self.b/2,pts_b)+0.01 
		print('sdfsdf')
		
		
		self.x = np.concatenate((x_t,x_r,x_b,x_l)) + self.xc
		self.y = np.concatenate((y_t,y_r,y_b,y_l)) + self.yc
		
	def rotate(self,theta):
		x_rot, y_rot = transform.rotate(self.x-self.xc,self.y-self.yc,theta)
		self.x = x_rot + self.xc
		self.y = y_rot + self.yc
		
	def rotate_about_center(self,theta):
		x_rot, y_rot = transform.rotate(self.x,self.y,theta)
		self.x = x_rot
		self.y = y_rot
		



import numpy as np



def rotate(x,y,theta):
	'''Rotates the coordinates (x,y) in anit-clockwise direction by an angle theta.
	theta is in the units of degrees.'''
	
	theta_rad = np.radians(theta)
	x_rot  = x*np.cos(-theta_rad) + y*np.sin(-theta_rad)
	y_rot  = -x*np.sin(-theta_rad) + y*np.cos(-theta_rad)
	
	
	return x_rot, y_rot
